@@ -396,10 +396,25 @@ gcm_prefs_combo_set_default_cb (gpointer user_data)
   return FALSE;
 }
 
+static gboolean
+gcm_prefs_profile_exists_in_array (GPtrArray *array, CdProfile *profile)
+{
+  CdProfile *profile_tmp;
+  guint i;
+
+  for (i = 0; i < array->len; i++)
+    {
+      profile_tmp = g_ptr_array_index (array, i);
+      if (cd_profile_equal (profile, profile_tmp))
+         return TRUE;
+    }
+  return FALSE;
+}
+
 static void
 gcm_prefs_add_profiles_suitable_for_devices (CcColorPanel *prefs,
                                              GtkWidget *widget,
-                                             CdProfile *profile)
+                                             GPtrArray *profiles)
 {
   CdProfile *profile_tmp;
   gboolean ret;
@@ -449,9 +464,12 @@ gcm_prefs_add_profiles_suitable_for_devices (CcColorPanel *prefs,
           goto out;
         }
 
-      /* don't add the current profile */
-      if (profile != NULL && cd_profile_equal (profile, profile_tmp))
-        continue;
+      /* don't add any of the already added profiles */
+      if (profiles != NULL)
+        {
+          if (gcm_prefs_profile_exists_in_array (profiles, profile_tmp))
+            continue;
+        }
 
       /* only add correct types */
       ret = gcm_prefs_is_profile_suitable_for_device (profile_tmp,
@@ -486,14 +504,14 @@ static void
 gcm_prefs_profile_add_cb (GtkWidget *widget, CcColorPanel *prefs)
 {
   const gchar *title;
-  CdProfile *profile = NULL;
+  GPtrArray *profiles;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* add profiles of the right kind */
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
                                                "combobox_profile"));
-  profile = cd_device_get_default_profile (priv->current_device);
-  gcm_prefs_add_profiles_suitable_for_devices (prefs, widget, profile);
+  profiles = cd_device_get_profiles (priv->current_device);
+  gcm_prefs_add_profiles_suitable_for_devices (prefs, widget, profiles);
 
   /* set the title */
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
@@ -532,8 +550,8 @@ gcm_prefs_profile_add_cb (GtkWidget *widget, CcColorPanel *prefs)
                                                "dialog_assign"));
   gtk_widget_show (widget);
   gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (priv->main_window));
-  if (profile != NULL)
-    g_object_unref (profile);
+  if (profiles != NULL)
+    g_ptr_array_unref (profiles);
 }
 
 static void
@@ -1750,8 +1768,6 @@ gcm_prefs_device_changed_cb (CdDevice *device, CcColorPanel *prefs)
   gchar *id_tmp;
   GtkTreeIter iter;
   GtkTreeModel *model;
-  GtkTreeSelection *selection;
-  GtkWidget *widget;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* get first element */
@@ -1769,13 +1785,8 @@ gcm_prefs_device_changed_cb (CdDevice *device, CcColorPanel *prefs)
                           -1);
       if (g_strcmp0 (id_tmp, id) == 0)
         {
-          /* populate device, and then select it */
+          /* populate device */
           gcm_prefs_device_set_model_by_iter (prefs, device, &iter);
-          widget = GTK_WIDGET (gtk_builder_get_object (priv->builder,
-                                                       "treeview_devices"));
-          selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
-          gtk_tree_selection_select_iter (selection, &iter);
-
         }
       g_free (id_tmp);
     } while (gtk_tree_model_iter_next (model, &iter));
@@ -1845,6 +1856,7 @@ gcm_prefs_remove_device (CcColorPanel *prefs, CdDevice *cd_device)
   const gchar *id;
   gchar *id_tmp;
   gboolean ret;
+  CdDevice *device_tmp;
   CcColorPanelPrivate *priv = prefs->priv;
 
   /* remove */
@@ -1864,8 +1876,15 @@ gcm_prefs_remove_device (CcColorPanel *prefs, CdDevice *cd_device)
                           -1);
       if (g_strcmp0 (id_tmp, id) == 0)
         {
+          gtk_tree_model_get (model, &iter,
+                              GCM_PREFS_COLUMN_DEVICE, &device_tmp,
+                              -1);
+          g_signal_handlers_disconnect_by_func (device_tmp,
+                                                G_CALLBACK (gcm_prefs_device_changed_cb),
+                                                prefs);
           gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
           g_free (id_tmp);
+          g_object_unref (device_tmp);
           break;
         }
       g_free (id_tmp);
